@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for elb service client paginators.
 
@@ -7,7 +8,7 @@ Usage::
     import boto3
 
     from mypy_boto3_elb import ElasticLoadBalancingClient
-    from mypy_boto3_elb import (
+    from mypy_boto3_elb.paginator import (
         DescribeAccountLimitsPaginator,
         DescribeLoadBalancersPaginator,
     )
@@ -18,40 +19,40 @@ Usage::
     describe_load_balancers_paginator: DescribeLoadBalancersPaginator = client.get_paginator("describe_load_balancers")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, List, TYPE_CHECKING
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_elb.type_defs import (
     DescribeAccessPointsOutputTypeDef,
     DescribeAccountLimitsOutputTypeDef,
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = ("DescribeAccountLimitsPaginator", "DescribeLoadBalancersPaginator")
 
 
 class DescribeAccountLimitsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeAccountLimits documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)
+    [Paginator.DescribeAccountLimits documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[DescribeAccountLimitsOutputTypeDef]:
         """
-        [DescribeAccountLimits.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits.paginate)
+        [DescribeAccountLimits.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits.paginate)
         """
 
 
 class DescribeLoadBalancersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeLoadBalancers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)
+    [Paginator.DescribeLoadBalancers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)
     """
 
     def paginate(
         self, LoadBalancerNames: List[str] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[DescribeAccessPointsOutputTypeDef]:
         """
-        [DescribeLoadBalancers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers.paginate)
+        [DescribeLoadBalancers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers.paginate)
         """
