@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 """
 Main interface for elb service client waiters.
 
@@ -7,7 +8,7 @@ Usage::
     import boto3
 
     from mypy_boto3_elb import ElasticLoadBalancingClient
-    from mypy_boto3_elb import (
+    from mypy_boto3_elb.waiter import (
         AnyInstanceInServiceWaiter,
         InstanceDeregisteredWaiter,
         InstanceInServiceWaiter,
@@ -20,18 +21,18 @@ Usage::
     instance_in_service_waiter: InstanceInServiceWaiter = client.get_waiter("instance_in_service")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import List, TYPE_CHECKING
-from botocore.waiter import Waiter as Boto3Waiter
-from mypy_boto3_elb.type_defs import InstanceTypeDef, WaiterConfigTypeDef
+from typing import List
 
+from botocore.waiter import Waiter as Boto3Waiter
+
+from mypy_boto3_elb.type_defs import InstanceTypeDef, WaiterConfigTypeDef
 
 __all__ = ("AnyInstanceInServiceWaiter", "InstanceDeregisteredWaiter", "InstanceInServiceWaiter")
 
 
 class AnyInstanceInServiceWaiter(Boto3Waiter):
     """
-    [Waiter.AnyInstanceInService documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
+    [Waiter.AnyInstanceInService documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
     """
 
     def wait(
@@ -41,13 +42,13 @@ class AnyInstanceInServiceWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [AnyInstanceInService.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService.wait)
+        [AnyInstanceInService.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService.wait)
         """
 
 
 class InstanceDeregisteredWaiter(Boto3Waiter):
     """
-    [Waiter.InstanceDeregistered documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
+    [Waiter.InstanceDeregistered documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
     """
 
     def wait(
@@ -57,13 +58,13 @@ class InstanceDeregisteredWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [InstanceDeregistered.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered.wait)
+        [InstanceDeregistered.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered.wait)
         """
 
 
 class InstanceInServiceWaiter(Boto3Waiter):
     """
-    [Waiter.InstanceInService documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
+    [Waiter.InstanceInService documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
     """
 
     def wait(
@@ -73,5 +74,5 @@ class InstanceInServiceWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [InstanceInService.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService.wait)
+        [InstanceInService.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService.wait)
         """
